@@ -23,6 +23,9 @@
 
 // INCLUDES
 
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include "Auth.hpp"
 #include "OptionContainer.hpp"
 
@@ -39,7 +42,7 @@ extern authcreate_t digestcreate;
 extern authcreate_t identcreate;
 extern authcreate_t ipcreate;
 
-#ifdef __NTLM
+#ifdef ENABLE_NTLM
 extern authcreate_t ntlmcreate;
 #endif
 
@@ -153,7 +156,7 @@ AuthPlugin* auth_plugin_load(const char *pluginConfigPath)
 		return ipcreate(cv);
 	}
 
-#ifdef __NTLM
+#ifdef ENABLE_NTLM
 	if (plugname == "proxy-ntlm") {
 #ifdef DGDEBUG
 		std::cout << "Enabling proxy-NTLM auth plugin" << std::endl;
