@@ -20,8 +20,9 @@
 
 // INCLUDES
 
-#include "platform.h"
-
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 #include "HTTPHeader.hpp"
 #include "OptionContainer.hpp"
 
@@ -34,12 +35,7 @@
 #include <fstream>
 #include <sys/time.h>
 #include <queue>
-
-#ifdef __GCCVER3
 #include <istream>
-#else
-#include <istream.h>
-#endif
 
 // DEFINES
 
@@ -248,7 +244,7 @@ bool DataBuffer::in(Socket * sock, Socket * peersock, HTTPHeader * requestheader
 }
 
 // send the request body to the client after having been handled by a DM plugin
-void DataBuffer::out(Socket * sock) throw(exception)
+void DataBuffer::out(Socket * sock) throw(std::exception)
 {
 	if (dontsendbody) {
 #ifdef DGDEBUG
@@ -275,7 +271,7 @@ void DataBuffer::out(Socket * sock) throw(exception)
 #ifdef DGDEBUG
 				std::cout << "error reading temp file so throwing exception" << std::endl;
 #endif
-				throw exception();
+				throw std::exception();
 			}
 			if (rc == 0) {
 #ifdef DGDEBUG
@@ -285,7 +281,7 @@ void DataBuffer::out(Socket * sock) throw(exception)
 			}
 			// as it's cached to disk the buffer must be reasonably big
 			if (!(*sock).writeToSocket(data, rc, 0, timeout)) {
-				throw exception();
+				throw std::exception();
 			}
 			sent += rc;
 #ifdef DGDEBUG
@@ -303,10 +299,10 @@ void DataBuffer::out(Socket * sock) throw(exception)
 		// it's in RAM, so just send it, no streaming from disk
 		if (buffer_length != 0) {
 			if (!(*sock).writeToSocket(data + bytesalreadysent, buffer_length - bytesalreadysent, 0, timeout))
-				throw exception();
+				throw std::exception();
 		} else {
 			if (!sock->writeToSocket("\r\n\r\n", 4, 0, timeout))
-				throw exception();
+				throw std::exception();
 		}
 	}
 }
@@ -431,11 +427,11 @@ void DataBuffer::zlibinflate(bool header)
 }
 
 // Does a regexp search and replace.
-	typedef struct newreplacement
-	{
-		int match;
-		String replacement;
-	};
+struct newreplacement
+{
+	int match;
+	String replacement;
+};
 bool DataBuffer::contentRegExp(int filtergroup)
 {
 
