@@ -29,6 +29,7 @@
 #include "FOptionContainer.hpp"
 #include "OptionContainer.hpp"
 
+#include <cstdlib>
 #include <syslog.h>
 #include <iostream>
 #include <fstream>
@@ -67,29 +68,7 @@ std::deque<String> * ipToHostname(const char *ip)
 
 FOptionContainer::~FOptionContainer()
 {
-	if (banned_phrase_flag) o.lm.deRefList(banned_phrase_list);
-	if (exception_site_flag) o.lm.deRefList(exception_site_list);
-	if (exception_url_flag) o.lm.deRefList(exception_url_list);
-	if (banned_extension_flag) o.lm.deRefList(banned_extension_list);
-	if (banned_mimetype_flag) o.lm.deRefList(banned_mimetype_list);
-	if (banned_site_flag) o.lm.deRefList(banned_site_list);
-	if (banned_url_flag) o.lm.deRefList(banned_url_list);
-	if (grey_site_flag) o.lm.deRefList(grey_site_list);
-	if (grey_url_flag) o.lm.deRefList(grey_url_list);
-	if (banned_regexpurl_flag) o.lm.deRefList(banned_regexpurl_list);
-	if (exception_regexpurl_flag) o.lm.deRefList(exception_regexpurl_list);
-	if (banned_regexpheader_flag) o.lm.deRefList(banned_regexpheader_list);
-	if (content_regexp_flag) o.lm.deRefList(content_regexp_list);
-	if (url_regexp_flag) o.lm.deRefList(url_regexp_list);
-	if (header_regexp_flag) o.lm.deRefList(header_regexp_list);
-	if (exception_extension_flag) o.lm.deRefList(exception_extension_list);
-	if (exception_mimetype_flag) o.lm.deRefList(exception_mimetype_list);
-	if (exception_file_site_flag) o.lm.deRefList(exception_file_site_list);
-	if (exception_file_url_flag) o.lm.deRefList(exception_file_url_list);
-	if (log_site_flag) o.lm.deRefList(log_site_list);
-	if (log_url_flag) o.lm.deRefList(log_url_list);
-	if (log_regexpurl_flag) o.lm.deRefList(log_regexpurl_list);
-	delete banned_page;
+	reset();
 }
 
 void FOptionContainer::reset()
@@ -116,6 +95,7 @@ void FOptionContainer::reset()
 	if (log_site_flag) o.lm.deRefList(log_site_list);
 	if (log_url_flag) o.lm.deRefList(log_url_list);
 	if (log_regexpurl_flag) o.lm.deRefList(log_regexpurl_list);
+
 	banned_phrase_flag = false;
 	exception_site_flag = false;
 	exception_url_flag = false;
@@ -205,7 +185,6 @@ bool FOptionContainer::read(const char *filename)
 	try {			// all sorts of exceptions could occur reading conf files
 		std::string linebuffer;
 		String temp;  // for tempory conversion and storage
-		int j;  // counter
 		std::ifstream conffiles(filename, std::ios::in);  // dansguardianfN.conf
 		if (!conffiles.good()) {
 			if (!is_daemonised) {
@@ -218,9 +197,6 @@ bool FOptionContainer::read(const char *filename)
 			getline(conffiles, linebuffer);
 			if (!conffiles.eof() && linebuffer.length() != 0) {
 				if (linebuffer[0] != '#') {	// i.e. not commented out
-					for (j = 0; j < (signed) linebuffer.length(); j++) {
-						linebuffer[j] = tolower(linebuffer[j]);
-					}
 					temp = (char *) linebuffer.c_str();
 					if (temp.contains("#")) {
 						temp = temp.before("#");
@@ -804,7 +780,7 @@ bool FOptionContainer::readbplfile(const char *banned, const char *exception, co
 			return false;
 		}
 
-		result = (*o.lm.l[banned_phrase_list]).readPhraseList(banned, false);
+		result = (*o.lm.l[banned_phrase_list]).readPhraseList(banned, false, -1, -1, false);
 		if (!result) {
 			if (!is_daemonised) {
 				std::cerr << "Error opening bannedphraselist" << std::endl;
@@ -816,7 +792,7 @@ bool FOptionContainer::readbplfile(const char *banned, const char *exception, co
 #ifdef DGDEBUG
 			std::cout << "Reading weighted phrase list" << std::endl;
 #endif
-			result = (*o.lm.l[banned_phrase_list]).readPhraseList(weighted, false);
+			result = (*o.lm.l[banned_phrase_list]).readPhraseList(weighted, false, -1, -1, false);
 			if (!result) {
 				if (!is_daemonised) {
 					std::cerr << "Error opening weightedphraselist" << std::endl;
