@@ -26,8 +26,6 @@
 
 // INCLUDES
 
-#include "platform.h"
-
 #include "String.hpp"
 #include "HTMLTemplate.hpp"
 #include "ListContainer.hpp"
@@ -58,7 +56,7 @@ public:
 	bool enable_PICS;
 	bool deep_url_analysis;
 
-#ifdef __EMAIL
+#ifdef ENABLE_EMAIL
 	// Email notification patch by J. Gauthier
 	bool notifyav;
 	bool notifycontent;
@@ -164,7 +162,7 @@ public:
 	std::string imagic;
 	std::string cookie_magic;
 
-#ifdef __EMAIL
+#ifdef ENABLE_EMAIL
 	// Email notification patch by J. Gauthier
 	std::string mailfrom;
 	std::string avadmin;
@@ -305,7 +303,7 @@ private:
 
 	int findoptionI(const char *option);
 	std::string findoptionS(const char *option);
-	bool realitycheck(int l, int minl, int maxl, char *emessage);
+	bool realitycheck(int l, int minl, int maxl, const char *emessage);
 	int inRegExpURLList(String &url, std::deque<RegExp> &list_comp, std::deque<unsigned int> &list_ref, unsigned int list);
 
 	char *inURLList(String &url, unsigned int list, bool doblanket = false, bool ip = false, bool ssl = false);
