@@ -24,6 +24,7 @@
 	#include "dgconfig.h"
 #endif
 
+#include <cstdlib>
 #include <syslog.h>
 #include <csignal>
 #include <ctime>
@@ -70,7 +71,6 @@ extern bool is_daemonised;
 
 int numchildren;  // to keep count of our children
 int busychildren;  // to keep count of our children
-int freechildren;  // to keep count of our children
 int waitingfor;  // num procs waiting for to be preforked
 int *childrenpids;  // so when one exits we know who
 int *childrenstates;  // so we know what they're up to
@@ -713,11 +713,11 @@ void deletechild(int child_pid)
 		if (childrenpids[i] == child_pid) {
 			childrenpids[i] = -1;
 			// Delete a busy child
-			if (childrenstates[i] == 1) {
+			if (childrenstates[i] == 1)
 				busychildren--;
-			}
 			// Delete a child which isn't "ready" yet
-			if (childrenstates[i] == 4) {
+			if (childrenstates[i] == 4)
+			{
 				busychildren--;
 				waitingfor--;
 			}
@@ -2012,7 +2012,7 @@ int fc_controlit()
 
 	numchildren = 0;  // to keep count of our children
 	busychildren = 0;  // to keep count of our children
-	freechildren = 0;  // to keep count of our children
+	int freechildren = 0;  // to keep count of our children
 
 	childrenpids = new int[o.max_children];  // so when one exits we know who
 	childrenstates = new int[o.max_children];  // so we know what they're up to
@@ -2092,9 +2092,7 @@ int fc_controlit()
 				reloadconfig = true;  // filter groups problem so lets
 				// try and reload entire config instead
 				// if that fails it will bomb out
-				o.lm.garbageCollect();
 			} else {
-				o.lm.garbageCollect();
 				if (o.use_filter_groups_list) {
 					o.filter_groups_list.reset();
 					if (!o.doReadItemList(o.filter_groups_list_location.c_str(),&(o.filter_groups_list),"filtergroupslist",true))
@@ -2111,6 +2109,7 @@ int fc_controlit()
 					}
 					if (!reloadconfig) {
 						hup_allchildren();
+						o.lm.garbageCollect();
 						prefork(o.min_children);
 						gentlereload = false;
 						// everything ok - no full reload needed
@@ -2155,6 +2154,7 @@ int fc_controlit()
 
 		if (tofind > 0) {
 			check_kid_readystatus(tofind);
+			mopup_afterkids();
 		}
 
 		freechildren = numchildren - busychildren;
@@ -2191,7 +2191,24 @@ int fc_controlit()
 #ifdef DGDEBUG
 						std::cout<<"telling child to accept "<<(i-o.max_children)<<std::endl;
 #endif
-						tellchild_accept(getfreechild(), i - o.max_children);
+						int childnum = getfreechild();
+						if (childnum < 0)
+						{
+							// Oops! weren't actually any free children.
+							// Not sure why as yet, but it seems this can
+							// sometimes happen. :(  PRA 2009-03-11
+							syslog(LOG_WARNING,
+								"No free children from getfreechild(): numchildren = %d, busychildren = %d, waitingfor = %d",
+								numchildren, busychildren, waitingfor
+							);
+							freechildren = 0;
+							usleep(1000);
+						}
+						else
+						{
+							tellchild_accept(childnum, i - o.max_children);
+							--freechildren;
+						}
 					} else {
 						usleep(1000);
 					}
