@@ -59,7 +59,7 @@ extern OptionContainer o;
 // IMPLEMENTATION
 
 // Constructor - set default values
-ListContainer::ListContainer():refcount(1), parent(false), filedate(0), used(false), bannedpfiledate(0), exceptionpfiledate(0), weightedpfiledate(0),
+ListContainer::ListContainer():refcount(0), parent(false), filedate(0), used(false), bannedpfiledate(0), exceptionpfiledate(0), weightedpfiledate(0),
 	blanketblock(false), blanket_ip_block(false), blanketsslblock(false), blanketssl_ip_block(false),
 	sourceisexception(false), sourcestartswith(false), sourcefilters(0), data(NULL), realgraphdata(NULL), maxchildnodes(0), graphitems(0),
 	data_length(0), data_memory(0), items(0), isSW(false), issorted(false), graphused(false), force_quick_search(false),
@@ -70,13 +70,7 @@ ListContainer::ListContainer():refcount(1), parent(false), filedate(0), used(fal
 // delete the memory block when the class is destryed
 ListContainer::~ListContainer()
 {
-	free(data);
-	if (graphused) {
-		free(realgraphdata);
-	}
-	for (unsigned int i = 0; i < morelists.size(); i++) {
-		o.lm.deRefList(morelists[i]);
-	}
+	reset();
 }
 
 // for both types of list - clear & reset all values
@@ -85,8 +79,20 @@ void ListContainer::reset()
 	free(data);
 	if (graphused)
 		free(realgraphdata);
-	for (unsigned int i = 0; i < morelists.size(); i++) {
-		o.lm.deRefList(morelists[i]);
+	// dereference this and included lists
+	// - but not if the reason we're being
+	// deleted is due to deletion (this will
+	// only happen due to list garbage
+	// collection, at which point the list
+	// ref should already be zero)
+	if (refcount > 0)
+	{
+		--refcount;
+#if DGDEBUG
+		std::cout << "de-reffing " << sourcefile << " due to manual list reset, refcount: " << refcount << std::endl;
+#endif
+		for (size_t i = 0; i < morelists.size(); ++i)
+			o.lm.deRefList(morelists[i]);
 	}
 	data = NULL;
 	realgraphdata = NULL;
@@ -140,8 +146,12 @@ bool ListContainer::previousUseItem(const char *filename, bool startswith, int f
 
 // for phrase lists - read in the given file, which may be an exception list
 // inherit category and time limits from parent
-bool ListContainer::readPhraseList(const char *filename, bool isexception, int catindex, int timeindex)
+bool ListContainer::readPhraseList(const char *filename, bool isexception, int catindex, int timeindex, bool incref)
 {
+	// only increment refcount on first read, not read of included files
+	// (includes get amalgamated, unlike item lists)
+	if (incref)
+		++refcount;
 	sourcefile = filename;
 	sourceisexception = isexception;
 	std::string linebuffer;  // a string line buffer ;)
@@ -192,7 +202,7 @@ bool ListContainer::readPhraseList(const char *filename, bool isexception, int c
 			else if (line.startsWith(".")) {
 				temp = line.after(".include<").before(">");
 				if (temp.length() > 0) {
-					if (!readPhraseList(temp.toCharArray(), isexception, catindex, timeindex)) {
+					if (!readPhraseList(temp.toCharArray(), isexception, catindex, timeindex, false)) {
 						listfile.close();
 						return false;
 					}
@@ -349,6 +359,7 @@ bool ListContainer::addToItemListPhrase(const char *s, size_t len, int type, int
 // for item lists - read item list from file. checkme - what is startswith? is it used? what is filters?
 bool ListContainer::readItemList(const char *filename, bool startswith, int filters)
 {
+	++refcount;
 #ifdef DGDEBUG
 	if (filters != 32)
 		std::cout << "Converting to lowercase" << std::endl;
@@ -362,7 +373,6 @@ bool ListContainer::readItemList(const char *filename, bool startswith, int filt
 #ifdef DGDEBUG
 	std::cout << filename << std::endl;
 #endif
-	filedate = getFileDate(filename);
 	if (isCacheFileNewer(filename)) {	// see if cached .process file
 		linebuffer = filename;  //         is available and up to date
 		linebuffer += ".processed";
@@ -372,11 +382,13 @@ bool ListContainer::readItemList(const char *filename, bool startswith, int filt
 			if (!readProcessedItemList(linebuffer.c_str(), startswith, filters)) {	// read cached
 				return false;
 			}
+			filedate = getFileDate(linebuffer.c_str());
 			issorted = true;  // don't bother sorting cached file
 			return true;
 
 		}
 	}
+	filedate = getFileDate(filename);
 	size_t len = 0;
 	try {
 		len = getFileLength(filename);
@@ -1049,16 +1061,16 @@ void ListContainer::graphCopyNodePhrases(unsigned int pos)
 	}
 }
 
-int ListContainer::bmsearch(char *file, int fl, const std::string& s)
+int ListContainer::bmsearch(char *file, off_t fl, const std::string& s)
 {
-	int pl = s.length();
+	off_t pl = s.length();
 	if (fl < pl)
 		return 0;  // reality checking
 	if (pl > 126)
 		return 0;  // reality checking
 
 	// must match all
-	int j, l;  // counters
+	off_t j, l;  // counters
 	int p;  // to hold precalcuated value for speed
 	bool match;  // flag
 	int qsBc[256];  // Quick Search Boyer Moore shift table (256 alphabet)
@@ -1118,10 +1130,10 @@ int ListContainer::bmsearch(char *file, int fl, const std::string& s)
 // Format of the data is each entry has GRAPHENTRYSIZE int values with format of:
 // [letter][last letter flag][num links][from phrase][link0][link1]...
 
-void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, unsigned int> >& result, char *doc, int len)
+void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, int> >& result, char *doc, off_t len)
 {
-	int i, j, k;
-	std::map<std::string, std::pair<unsigned int, unsigned int> >::iterator existingitem;
+	off_t i, j, k;
+	std::map<std::string, std::pair<unsigned int, int> >::iterator existingitem;
 	
 	//do standard quick search on short branches (or everything, if force_quick_search is on)
 	for (std::vector<unsigned int>::iterator i = slowgraph.begin(); i != slowgraph.end(); i++) {
@@ -1130,7 +1142,7 @@ void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, un
 		for (k = 0; k < j; k++) {
 			existingitem = result.find(phrase);
 			if (existingitem == result.end()) {
-				result[phrase] = std::pair<unsigned int, unsigned int>(*i, 1);
+				result[phrase] = std::pair<unsigned int, int>(*i, 1);
 			} else {
 				existingitem->second.second++;
 			}
@@ -1140,7 +1152,7 @@ void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, un
 	if (force_quick_search || graphitems == 0) {
 #ifdef DGDEBUG
 		std::cout << "Map (quicksearch) start" << std::endl;
-		for (std::map<std::string, std::pair<unsigned int, unsigned int> >::iterator i = result.begin(); i != result.end(); i++) {
+		for (std::map<std::string, std::pair<unsigned int, int> >::iterator i = result.begin(); i != result.end(); i++) {
 			std::cout << "Map: " << i->first << " " << i->second.second << std::endl;
 		}
 		std::cout << "Map (quicksearch) end" << std::endl;
@@ -1148,14 +1160,14 @@ void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, un
 		return;
 	}
 	
-	int sl;
-	int ppos;
-	int currnode;
+	off_t sl;
+	off_t ppos;
+	off_t currnode;
 	int * graphdata = realgraphdata;
-	int ml;
+	off_t ml;
 	char p;
-	int pos;
-	int depth;
+	off_t pos;
+	off_t depth;
 	// number of links from root node to first letter of phrase
 	ml = graphdata[2] + 4;
 	// iterate over entire document
@@ -1188,7 +1200,7 @@ void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, un
 						std::string phrase = getItemAtInt(graphdata[ppos + 3]);
 						existingitem = result.find(phrase);
 						if (existingitem == result.end()) {
-							result[phrase] = std::pair<unsigned int, unsigned int>(graphdata[ppos + 3], 1);
+							result[phrase] = std::pair<unsigned int, int>(graphdata[ppos + 3], 1);
 						} else {
 							existingitem->second.second++;
 						}
@@ -1231,7 +1243,7 @@ void ListContainer::graphSearch(std::map<std::string, std::pair<unsigned int, un
 	}
 #ifdef DGDEBUG
 	std::cout << "Map start" << std::endl;
-	for (std::map<std::string, std::pair<unsigned int, unsigned int> >::iterator i = result.begin(); i != result.end(); i++) {
+	for (std::map<std::string, std::pair<unsigned int, int> >::iterator i = result.begin(); i != result.end(); i++) {
 		std::cout << "Map: " << i->first << " " << i->second.second << std::endl;
 	}
 	std::cout << "Map end" << std::endl;
@@ -1636,7 +1648,7 @@ void ListContainer::increaseMemoryBy(size_t bytes)
 	}
 }
 
-size_t ListContainer::getFileLength(const char *filename)
+size_t getFileLength(const char *filename)
 {
 	struct stat status;
 	int rc = stat(filename, &status);
@@ -1645,22 +1657,18 @@ size_t ListContainer::getFileLength(const char *filename)
 	return status.st_size;
 }
 
-int ListContainer::getFileDate(const char *filename)
+time_t getFileDate(const char *filename)
 {
 	struct stat status;
 	int rc = stat(filename, &status);
-	if (rc != 0) {
-		return -1;
+	if (rc != 0)
+	{
+		if (errno == ENOENT)
+			return 0;
+		else
+			throw std::runtime_error(strerror(errno));
 	}
-	struct tm *tmnow = localtime(&status.st_mtime);
-
-	int date = (tmnow->tm_year - 100) * 31536000;
-	date += tmnow->tm_mon * 2628000;
-	date += tmnow->tm_mday * 86400;
-	date += tmnow->tm_hour * 3600;
-	date += tmnow->tm_min * 60;
-	date += tmnow->tm_sec;
-	return date;  // a nice int rather than a horrid struct
+	return status.st_mtime;
 }
 
 bool ListContainer::upToDate()
@@ -1668,6 +1676,13 @@ bool ListContainer::upToDate()
 	if (getFileDate(sourcefile.toCharArray()) > filedate) {
 		return false;
 	}
+
+	String cachefile(sourcefile);
+	cachefile += ".processed";
+	if (getFileDate(cachefile.toCharArray()) > filedate) {
+		return false;
+	}
+
 	for (unsigned int i = 0; i < morelists.size(); i++) {
 		if (!(*o.lm.l[morelists[i]]).upToDate()) {
 			return false;
@@ -1743,13 +1758,13 @@ bool ListContainer::readTimeTag(String * tag, TimeLimit& tl)
 // included lists don't have their own ListContainer, so time limits are stored differently.
 bool ListContainer::isNow(int index)
 {
+	if (!istimelimited) {
+		return true;
+	}
 	TimeLimit& tl = listtimelimit;
 	if (index > -1) {
 		tl = timelimits[index];
 	}
-	if (!istimelimited) {
-		return true;
-	}
 	time_t tnow;  // to hold the result from time()
 	struct tm *tmnow;  // to hold the result from localtime()
 	unsigned int hour, min, wday;
