@@ -48,22 +48,6 @@ ListManager::~ListManager()
 	}
 }
 
-// reduce the reference count on the given list identifier
-void ListManager::deRefList(unsigned int item)
-{
-#ifdef DGDEBUG
-	std::cout << "de-reffing: " << item << std::endl;
-#endif
-
-	if ((item + 1) > l.size()) {
-		return;  // should only happen if when a list was generated
-		// there was a problem so the list ref is bad
-	}
-	if (l[item] != NULL) {
-		(*l[item]).refcount--;
-	}
-}
-
 // find an unused list in our collection of lists
 int ListManager::findNULL()
 {
@@ -94,40 +78,40 @@ void ListManager::garbageCollect()
 	}
 }
 
-// get the modification date of the given file in seconds
-int ListManager::getFileDate(const char *filename)
+void ListManager::deRefList(size_t i)
 {
-	struct stat status;
-	int rc = stat(filename, &status);
-	if (rc != 0) {
-		return -1;
-	}
-	struct tm *tmnow = localtime(&status.st_mtime);
+	l[i]->refcount--;
+#ifdef DGDEBUG
+	std::cout << "de-referencing list ref: " << i << ", refcount: " << l[i]->refcount << " (" << l[i]->sourcefile << ")" << std::endl;
+#endif
+	for (size_t j = 0; j < l[i]->morelists.size(); ++j)
+		deRefList(l[i]->morelists[j]);
+}
 
-	int date = (tmnow->tm_year - 100) * 31536000;
-	date += tmnow->tm_mon * 2628000;
-	date += tmnow->tm_mday * 86400;
-	date += tmnow->tm_hour * 3600;
-	date += tmnow->tm_min * 60;
-	date += tmnow->tm_sec;
-	return date;  // a nice int rather than a horrid struct
+void ListManager::refList(size_t i)
+{
+	l[i]->refcount++;
+#ifdef DGDEBUG
+	std::cout << "referencing list ref: " << i << ", refcount: " << l[i]->refcount << " (" << l[i]->sourcefile << ")" << std::endl;
+#endif
+	for (size_t j = 0; j < l[i]->morelists.size(); ++j)
+		refList(l[i]->morelists[j]);
 }
 
 // load the given list, or increase refcount on list if it's already been loaded.
 int ListManager::newItemList(const char *filename, bool startswith, int filters, bool parent)
 {
-	for (unsigned int i = 0; i < l.size(); i++) {
+	for (size_t i = 0; i < l.size(); i++) {
 		if (l[i] == NULL) {
 			continue;
 		}
 		if ((*l[i]).previousUseItem(filename, startswith, filters)) {
 			// this upToDate check also checks all .Included files
 			if ((*l[i]).upToDate()) {
-				(*l[i]).refcount++;
 #ifdef DGDEBUG
 				std::cout << "Using previous item: " << i << " " << filename << std::endl;
-				std::cout << "refcount: " << l[i]->refcount << std::endl;
 #endif
+				refList(i);
 				return i;
 			}
 		}
@@ -157,10 +141,10 @@ int ListManager::newItemList(const char *filename, bool startswith, int filters,
 // pass in exception, banned, and weighted phrase lists all at once.
 int ListManager::newPhraseList(const char *exception, const char *banned, const char *weighted)
 {
-	int bannedpfiledate = getFileDate(banned);
-	int exceptionpfiledate = getFileDate(exception);
-	int weightedpfiledate = getFileDate(weighted);
-	for (unsigned int i = 0; i < l.size(); i++) {
+	time_t bannedpfiledate = getFileDate(banned);
+	time_t exceptionpfiledate = getFileDate(exception);
+	time_t weightedpfiledate = getFileDate(weighted);
+	for (size_t i = 0; i < l.size(); i++) {
 		if (l[i] == NULL) {
 			continue;
 		}
@@ -173,11 +157,10 @@ int ListManager::newPhraseList(const char *exception, const char *banned, const
 				//so when phrases read in in list container it needs to store
 				//all the file names and if a single one has changed needs a
 				//complete regenerate
-				(*l[i]).refcount++;
 #ifdef DGDEBUG
 				std::cout << "Using previous phrase: " << exception << " - " << banned << " - " << weighted << std::endl;
-				std::cout << "refcount: " << l[i]->refcount << std::endl;
 #endif
+				refList(i);
 				return i;
 			}
 		}
