@@ -48,8 +48,8 @@ public:
 	// does not call readPhraseList. (checkme: why?)
 	int newPhraseList(const char *exception, const char *banned, const char *weighted);
 	
-	// reduce the reference count on a list
-	void deRefList(unsigned int item);
+	void deRefList(size_t item);
+	
 	// delete lists with refcount zero
 	void garbageCollect();
 
@@ -57,8 +57,7 @@ private:
 	// find an empty slot in our collection of listcontainters
 	int findNULL();
 	
-	// find file modification date
-	int getFileDate(const char *filename);
+	void refList(size_t item);
 };
 
 #endif
