@@ -29,10 +29,7 @@
 
 #include <iostream>
 #include <fstream>
-#include <netdb.h>		// for gethostby
-#include <netinet/in.h>		// for address structures
-#include <arpa/inet.h>		// for inet_aton()
-#include <sys/socket.h>
+#include <sstream>
 #include <syslog.h>
 
 #include <unistd.h>		// checkme: remove?
@@ -51,10 +48,7 @@ OptionContainer::OptionContainer():numfg(0)
 
 OptionContainer::~OptionContainer()
 {
-	deleteFilterGroups();
-	deletePlugins(dmplugins);
-	deletePlugins(csplugins);
-	deletePlugins(authplugins);
+	reset();
 }
 
 void OptionContainer::reset()
@@ -107,7 +101,6 @@ bool OptionContainer::read(const char *filename, int type)
 	try {
 		std::string linebuffer;
 		String temp;  // for tempory conversion and storage
-		int j;  // counter
 		std::ifstream conffiles(filename, std::ios::in);  // dansguardian.conf
 		if (!conffiles.good()) {
 			if (!is_daemonised) {
@@ -120,9 +113,6 @@ bool OptionContainer::read(const char *filename, int type)
 			getline(conffiles, linebuffer);
 			if (!conffiles.eof() && linebuffer.length() != 0) {
 				if (linebuffer[0] != '#') {	// i.e. not commented out
-					for (j = 0; j < (signed) linebuffer.length(); j++) {
-						linebuffer[j] = tolower(linebuffer[j]);
-					}
 					temp = (char *) linebuffer.c_str();
 					if (temp.contains("#")) {
 						temp = temp.before("#");
@@ -381,6 +371,14 @@ bool OptionContainer::read(const char *filename, int type)
 			return false;
 		}
 
+#ifdef ENABLE_ORIG_IP
+		if (findoptionS("originalip") == "off") {
+			get_orig_ip = false;
+		} else {
+			get_orig_ip = true;
+		}
+#endif
+
 		ll = findoptionI("loglevel");
 		if (!realitycheck(ll, 0, 3, "loglevel")) {
 			return false;
@@ -763,9 +761,9 @@ bool OptionContainer::readFilterGroupConf()
 		file = prefix + String(i);
 		file += ".conf";
 		if (use_group_names_list) {
-			std::string optname("GROUP");
-			optname += (char)(i + 64);
-			groupname = groupnamesfile[optname.c_str()];
+			std::ostringstream groupnum;
+			groupnum << i;
+			groupname = groupnamesfile[groupnum.str().c_str()];
 			if (groupname.length() == 0) {
 				if (!is_daemonised)
 					std::cerr << "Group names file too short: " << group_names_list_location << std::endl;
