@@ -19,6 +19,9 @@
 
 
 // INCLUDES
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 
 #include "../Auth.hpp"
 #include "../OptionContainer.hpp"
@@ -105,7 +108,7 @@ int identinstance::identify(Socket& peercon, Socket& proxycon, HTTPHeader &h, st
 	char buff[8192];
 	try {
 		iq.getLine(buff, 8192, 5);
-	} catch(exception & e) {
+	} catch(std::exception & e) {
 		return -2;
 	}
 	String temp;
