@@ -19,6 +19,9 @@
 
 
 // INCLUDES
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 
 #include "../DownloadManager.hpp"
 #include "../OptionContainer.hpp"
@@ -206,7 +209,7 @@ int dminstance::in(DataBuffer * d, Socket * sock, Socket * peersock, class HTTPH
 			block = new char[newsize];
 			try {
 				sock->checkForInput(d->timeout);
-			} catch(exception & e) {
+			} catch(std::exception & e) {
 				break;
 			}
 			// improved more efficient socket read which uses the buffer better
@@ -234,7 +237,7 @@ int dminstance::in(DataBuffer * d, Socket * sock, Socket * peersock, class HTTPH
 			try {
 				sock->checkForInput(d->timeout);
 			}
-			catch(exception & e) {
+			catch(std::exception & e) {
 				break;
 			}
 			rc = d->bufferReadFromSocket(sock, d->data,
