@@ -17,6 +17,9 @@
 
 
 // INCLUDES
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 
 #include "../DownloadManager.hpp"
 #include "../OptionContainer.hpp"
@@ -381,7 +384,7 @@ int fancydm::in(DataBuffer * d, Socket * sock, Socket * peersock, class HTTPHead
 			block = new char[newsize];
 			try {
 				sock->checkForInput(d->timeout);
-			} catch(exception & e) {
+			} catch(std::exception & e) {
 				break;
 			}
 			// improved more efficient socket read which uses the buffer better
@@ -408,7 +411,7 @@ int fancydm::in(DataBuffer * d, Socket * sock, Socket * peersock, class HTTPHead
 			try {
 				sock->checkForInput(d->timeout);
 			}
-			catch(exception & e) {
+			catch(std::exception & e) {
 				break;
 			}
 			rc = d->bufferReadFromSocket(sock, d->data,
