@@ -24,6 +24,9 @@
 
 
 // INCLUDES
+#ifdef HAVE_CONFIG_H
+	#include "dgconfig.h"
+#endif
 
 #include "../DownloadManager.hpp"
 #include "../OptionContainer.hpp"
@@ -238,7 +241,7 @@ int trickledm::in(DataBuffer * d, Socket * sock, Socket * peersock, class HTTPHe
 			block = new char[newsize];
 			try {
 				sock->checkForInput(d->timeout);
-			} catch(exception & e) {
+			} catch(std::exception & e) {
 				break;
 			}
 			// improved more efficient socket read which uses the buffer better
@@ -266,7 +269,7 @@ int trickledm::in(DataBuffer * d, Socket * sock, Socket * peersock, class HTTPHe
 			try {
 				sock->checkForInput(d->timeout);
 			}
-			catch(exception & e) {
+			catch(std::exception & e) {
 				break;
 			}
 			rc = d->bufferReadFromSocket(sock, d->data,
